package ad.creuroja.gestio.services.impl;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Restrictions;

import ad.creuroja.gestio.models.Login;
import ad.creuroja.gestio.utils.HibernateUtil;

/**
 * Service con todas las operaciones sobre Logins
 * @author Adrian Chavero Ramos
 * @version 9 de ene. de 2016
 */
public class LoginServiceImpl {

	/**
	 * Es un login valido?
	 * @param username
	 * @param password
	 * @return true si existe el login y el password coencide, false si no.
	 */
	public boolean login(String username, String password) {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		Criteria criteria = session.createCriteria(Login.class);
		criteria.add(Restrictions.eq("username", username));
		criteria.add(Restrictions.eq("password", password));

		boolean result = false;
		if (criteria.uniqueResult() != null) {
			result = true;
		}

		session.flush();
		session.getTransaction().commit();

		return result;
	}

	/**
	 * Recupera un login a partir de su id
	 * @param id el id del login
	 * @return Login la instancia de Login con el id pasado por parametro
	 */
	public Login get(long id) {

		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();
		Login login = session.get(Login.class, id);
		session.flush();
		session.getTransaction().commit();

		return login;
	}

	/**
	 * Eliminar un login a partir de su id
	 * @param id el id del login
	 * @return true si fue eliminado, false no fue eliminado
	 */
	public boolean delete(long id) {

		boolean result=false;
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();
		Login login = session.get(Login.class, id);
		if (login!=null) {
			session.delete(login);
			result=true;
		}
		session.flush();
		session.getTransaction().commit();

		return result;
	}

	/**
	 * Añadir un login
	 * @param login el login a insertar
	 * @return true si fue añadido, false si no fue añadido
	 */
	public boolean addLogin(Login login) {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		Criteria criteria = session.createCriteria(Login.class);
		criteria.add(Restrictions.eq("username", login.getUsername()));
		if (criteria.uniqueResult()!=null) {
			session.flush();
			session.getTransaction().commit();

			return false;
		}

	    session.save(login);

		session.flush();
		session.getTransaction().commit();

		return true;
	}

	/**
	 * Añadir el login root
	 * @return false si ya existia, true si fue añadido
	 */
	public boolean addLoginRootMaster() {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		Criteria criteria = session.createCriteria(Login.class);
		criteria.add(Restrictions.eq("username", "root"));
		if (criteria.uniqueResult()!=null) {
			session.flush();
			session.getTransaction().commit();

			return false;
		}

	    session.save(new Login("root", "master", "root@gmail.com", "root", "toor"));

		session.flush();
		session.getTransaction().commit();

		return true;
	}

	/**
	 * Modificar un login
	 * @param login el login modificado
	 * @return true
	 */
	public boolean modLogin(Login login) {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		session.update(login);

		session.getTransaction().commit();

		return true;
	}

	/**
	 * Recuperar la lista de logins
	 * @return la lista de logins
	 */
	public List<Login> loginList() {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		Criteria criteria = session.createCriteria(Login.class);

		List<Login> result = criteria.list();

		session.flush();
		session.getTransaction().commit();

		return result;
	}

}
