package ad.creuroja.gestio.services.impl;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;

import ad.creuroja.gestio.models.TeleAssistUser;
import ad.creuroja.gestio.utils.HibernateUtil;

/**
 * Servicio con las operaciones sobre los usuarios de teleasistencia
 * @author Adrian Chavero Ramos
 * @version 9 de ene. de 2016
 */
public class TeleAssistUserServiceImpl {

	/**
	 * Recueperar un usuarios de teleasistencia a partir de su id
	 * @param id el id del usuario de teleasistencia
	 * @return la instancia de TeleAssistUser
	 */
	public TeleAssistUser get(long id) {

		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();
		TeleAssistUser teleAssistUser = session.get(TeleAssistUser.class, id);
		session.flush();
		session.getTransaction().commit();

		return teleAssistUser;
	}

	/**
	 * Eliminar un usuario de teleasistencia
	 * @param id el id del usuario de teleasistencia
	 * @return true si fue eliminado, false si no fue eliminado
	 */
	public boolean delete(long id) {

		boolean result=false;
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();
		TeleAssistUser teleAssistUser = session.get(TeleAssistUser.class, id);
		if (teleAssistUser!=null) {
			session.delete(teleAssistUser);
			result=true;
		}
		session.flush();
		session.getTransaction().commit();

		return result;
	}

	/**
	 * Añaidir un usuario de teleasistencia
	 * @param teleAssistUser la instancia a añadir
	 * @return true
	 */
	public boolean addTeleAssistUser(TeleAssistUser teleAssistUser) {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

	    session.save(teleAssistUser);

		session.flush();
		session.getTransaction().commit();

		return true;
	}

	/**
	 * Modificar un usuario de teleasistencia
	 * @param teleAssistUser la instancia a modificar
	 * @return true
	 */
	public boolean modTeleAssistUser(TeleAssistUser teleAssistUser) {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		session.update(teleAssistUser);

		session.getTransaction().commit();

		return true;
	}

	/**
	 * Recuperar la lista de usuarios de teleasistencia
	 * @return la lista de usuarios de teleasistencia
	 */
	public List<TeleAssistUser> teleAssistUserList() {
		Session session = HibernateUtil.getSessionFactory().getCurrentSession();
		session.beginTransaction();

		Criteria criteria = session.createCriteria(TeleAssistUser.class);

		List<TeleAssistUser> result = criteria.list();

		session.flush();
		session.getTransaction().commit();

		return result;
	}

}
