package com.achavero.cvf.core;

import java.util.HashMap;
import java.util.Map;

/**
 * Factory para retornar los diferentes Interceptores
 * a partir del nombre de la clase implementacin del interceptor
 * es singleton
 * @author Adrian Chavero Ramos
 * @version 20 de dic. de 2015
 */
public class CvfInterceptorSingletonFactory {
	protected Map<String, CvfInterceptor> interceptorsMap;

	public CvfInterceptorSingletonFactory() {
		this.interceptorsMap = new HashMap<>();
	}

	public CvfInterceptor getCvfInterceptor(String className) {
		CvfInterceptor interceptor =  null;
		if (className==null || className.equals("")) {
			interceptor = new CvfInterceptor() {
				@Override
				public boolean interceptPreProcess(CvfRequestInvocation invocation) {
					return true;
				}

				@Override
				public void interceptPostProcess(CvfRequestInvocation invocation) {
					return ;
				}
			};
		} else if (this.interceptorsMap.containsKey(className)) {
			interceptor = this.interceptorsMap.get(className);
		} else {
			try {
				interceptor = (CvfInterceptor) Class.forName(className).newInstance();
				interceptor.init();
				this.interceptorsMap.put(className, interceptor);
			} catch (InstantiationException | IllegalAccessException | ClassNotFoundException
			        | NullPointerException e) {
				System.err.println("getCvfInterceptor: " + e);
			}
		}
		return interceptor;
	}
}
