package com.achavero.cvf.core;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Clase helper para mantener en memoria la configuracin de las peticiones (URI + comando/accin)
 * se carag a partir del cvf.xml
 * @author Adrian Chavero Ramos
 * @version 20 de dic. de 2015
 */
public class CvfRequest {
	/**
	 * nombre de la peticin
	 */
	protected String name;

	/**
	 * Tipo de la peticin (view o action)
	 * junto al name forman la URI name.type ex: userList.view; userAdd.action
	 */
	protected String type;

	/**
	 *	Clase que implementa el comando/accin CvfRequestCommand
	 */
	protected String className;

	/**
	 * Lista de interceptores que se ejecutarn para esta peticin
	 */
	protected List<String> interceptorList;

	/**
	 * Mapa de resultados. resultado -> URI
	 */
	protected Map<String, String> resultsMap;

	public CvfRequest() {
		this.name = null;
		this.type = null;
		this.className = null;
		this.resultsMap = null;
	}

	public CvfRequest(String name, String type, String className) {
		this.name = name;
		this.type = type;
		this.className = className;

		this.interceptorList = new ArrayList<>();
		this.resultsMap = new HashMap<>();
	}

	public void putResult(String name, String url)  {
		this.resultsMap.put(name, url);
	}

	public String getName() {
		return this.name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getType() {
		return this.type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getClassName() {
		return this.className;
	}

	public void setClassName(String className) {
		this.className = className;
	}

	public String getUrlResult(String name) {
		return this.resultsMap.get(name);
	}

	public List<String> getInterceptorList() {
		return this.interceptorList;
	}

	public void setInterceptorList(List<String> interceptorList) {
		this.interceptorList = interceptorList;
	}

	public void addInterceptor(String interceptor) {
		this.interceptorList.add(interceptor);
	}

	public void removeInterceptor(String interceptor) {
		this.interceptorList.remove(interceptor);
	}
}