package com.achavero.cvf.core;

import java.util.HashMap;
import java.util.Map;

/**
 * Factory para retornar los diferentes comandos/acciones
 * a partir del nombre de la clase implementacin del comando/accin
 * es singleton
 * @author Adrian Chavero Ramos
 * @version 20 de dic. de 2015
 */
public class CvfRequestCommandSingletonFactory {
	protected Map<String, CvfRequestCommand> commandsMap;

	public CvfRequestCommandSingletonFactory() {
		this.commandsMap = new HashMap<>();
	}

	public CvfRequestCommand getCvfRequestCommand(String className) {
		CvfRequestCommand command =  null;
		if (className==null || className.equals("")) {
			command = new CvfRequestCommand() {
				@Override
				public String execute(CvfRequestInvocation invocation) {
					return "";
				}
			};
		} else if (this.commandsMap.containsKey(className)) {
			command = this.commandsMap.get(className);
		} else {
			try {
				command = (CvfRequestCommand) Class.forName(className).newInstance();
				command.init();
				this.commandsMap.put(className, command);
			} catch (InstantiationException | IllegalAccessException | ClassNotFoundException
			        | NullPointerException e) {
				System.err.println("getCvfRequestCommand: " + e);
			}
		}
		return command;
	}
}
