package com.achavero.cvf.core;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Clase que encapsula todos los objetos relaciones con la invocacin de una peticin
 *
 */
public class CvfRequestInvocation {
	protected CvfRequest cvfRequest;
	protected CvfRequestCommand command;
	protected CvfInterceptorSingletonFactory cvfInterceptorSingletonFactory;
	protected HttpServletRequest request;
	protected HttpServletResponse response;

	protected int interceptorIndex;

	public CvfRequestInvocation(CvfRequest cvfRequest, CvfRequestCommand command,
			CvfInterceptorSingletonFactory cvfInterceptorSingletonFactory, HttpServletRequest request, HttpServletResponse response) {
		this.cvfRequest = cvfRequest;
		this.command = command;
		this.cvfInterceptorSingletonFactory = cvfInterceptorSingletonFactory;
		this.request = request;
		this.response = response;

		this.interceptorIndex = 0;
	}

	// metodo recursivo, se llama por cada interceptor de la lista de interceptores
	// cuando no quedan interceptores se llama el metodo execute del comando/accin
	public String invoke() {
		if (this.interceptorIndex < this.cvfRequest.getInterceptorList().size()) {
			String interceptorClassName = this.cvfRequest.getInterceptorList().get(this.interceptorIndex);
			CvfInterceptor interceptor = this.cvfInterceptorSingletonFactory.getCvfInterceptor(interceptorClassName);
			this.interceptorIndex++;
			return interceptor.intercept(this);
		} else {
			return this.command.execute(this);
		}
	}

	public CvfRequest getCvfRequest() {
		return this.cvfRequest;
	}

	public CvfRequestCommand getCommand() {
		return this.command;
	}

	public HttpServletRequest getRequest() {
		return this.request;
	}

	public HttpServletResponse getResponse() {
		return this.response;
	}

}
