package com.achavero.utils;

import java.util.Date;

import javax.servlet.http.HttpServletRequest;

/**
 * Clase de utilidad para recuperar valores en el request,
 * con valores por defecto
 * @author Adrian Chavero Ramos
 * @version 20 de dic. de 2015
 */
public class Utils {

	/**
	 * @param request
	 * @param parameterName
	 * @param defaultValue
	 * @return the generic object in request attribute casted
	 */
	public static <T> T getAttribute(HttpServletRequest request, String parameterName, T defaultValue) {
		Object o = request.getAttribute(parameterName);
		if (o == null) {
			return defaultValue;
		}
		if (!o.getClass().equals(defaultValue.getClass())) {
			return defaultValue;
		}
		T result = (T) o;
		return result;
	}

	/**
	 * Must use that one and not <T> T getAttribute(HttpServletRequest request,
	 * String parameterName, T defaultValue) in case that the T defaultValue is
	 * null
	 *
	 * @param request
	 * @param parameterName
	 * @param defaultValue
	 * @return the generic object in request casted
	 */
	public static <T> T getAttribute(HttpServletRequest request, String parameterName, T defaultValue, Class<T> clazz) {
		Object o = request.getAttribute(parameterName);
		if (o != null) {
			return (clazz.cast(o));
		}
		return Utils.getAttribute(request, parameterName, defaultValue);
	}

	/**
	 * @param request
	 * @param parameterName
	 * @param defaultValue
	 * @return the generic object in request parameter casted
	 */
	public static <T> T getParameter(HttpServletRequest request, String parameterName, T defaultValue) {
		T result = null;
		String resultTemp = request.getParameter(parameterName);
		if (resultTemp == null) {
			return defaultValue;
		}
		if (defaultValue.getClass() == String.class) {
			result = (T) resultTemp;
		}
		if (defaultValue.getClass() == Integer.class || defaultValue.getClass() == int.class) {
			try {
				result = (T) new Integer(Integer.parseInt(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (defaultValue.getClass() == Float.class || defaultValue.getClass() == float.class) {
			try {
				result = (T) new Float(Float.parseFloat(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (defaultValue.getClass() == Double.class || defaultValue.getClass() == double.class) {
			try {
				result = (T) new Double(Double.parseDouble(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (defaultValue.getClass() == Boolean.class || defaultValue.getClass() == boolean.class) {
			try {
				result = (T) new Boolean(Boolean.parseBoolean(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (defaultValue.getClass() == Date.class) {
//			result = (T) DateUtils.getDate(resultTemp);
			if (result == null) {
				result = defaultValue;
			}
		}

		return result;
	}

	/**
	 * Must use that one and not <T> T getParameter(HttpServletRequest request,
	 * String parameterName, T defaultValue) in case that the T defaultValue is
	 * null
	 *
	 * @param request
	 * @param parameterName
	 * @param defaultValue
	 * @return the generic object in request casted
	 */
	public static <T> T getParameter(HttpServletRequest request, String parameterName, T defaultValue, Class<T> clazz) {
		T result = null;
		String resultTemp = request.getParameter(parameterName);
		if (resultTemp == null) {
			return defaultValue;
		}
		if (clazz == String.class) {
			result = (T) resultTemp;
		}
		if (clazz == Integer.class || clazz == int.class) {
			try {
				result = (T) new Integer(Integer.parseInt(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (clazz == Long.class || clazz == long.class) {
			try {
				result = (T) new Long(Long.parseLong(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (clazz == Float.class || clazz == float.class) {
			try {
				result = (T) new Float(Float.parseFloat(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (clazz == Double.class || clazz == double.class) {
			try {
				result = (T) new Double(Double.parseDouble(resultTemp));
			} catch (NumberFormatException nfe) {
				result = defaultValue;
			}
		}
		if (clazz == Boolean.class || clazz == boolean.class) {
			result = (T) new Boolean(Boolean.parseBoolean(resultTemp));
		}
		if (clazz == Date.class) {
//			result = (T) DateUtils.getDate(resultTemp);
			if (result == null) {
				result = defaultValue;
			}
		}

		return result;
	}
}
